==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/IntegrationRuntimeSsisCatalogInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs.builder
import com.pulumi.azurenative.synapse.kotlin.enums.IntegrationRuntimeSsisCatalogPricingTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Catalog information for managed dedicated integration runtime.
 * @property catalogAdminPassword The password of the administrator user account of the catalog database.
 * @property catalogAdminUserName The administrator user name of catalog database.
 * @property catalogPricingTier The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
 * @property catalogServerEndpoint The catalog database server URL.
 */
public data class IntegrationRuntimeSsisCatalogInfoArgs(
    public val catalogAdminPassword: Output<SecureStringArgs>? = null,
    public val catalogAdminUserName: Output<String>? = null,
    public val catalogPricingTier: Output<Either<String, IntegrationRuntimeSsisCatalogPricingTier>>? =
        null,
    public val catalogServerEndpoint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs =
        com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs.builder()
            .catalogAdminPassword(
                catalogAdminPassword?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .catalogAdminUserName(catalogAdminUserName?.applyValue({ args0 -> args0 }))
            .catalogPricingTier(
                catalogPricingTier?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .catalogServerEndpoint(catalogServerEndpoint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IntegrationRuntimeSsisCatalogInfoArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeSsisCatalogInfoArgsBuilder internal constructor() {
    private var catalogAdminPassword: Output<SecureStringArgs>? = null

    private var catalogAdminUserName: Output<String>? = null

    private var catalogPricingTier: Output<Either<String, IntegrationRuntimeSsisCatalogPricingTier>>? =
        null

    private var catalogServerEndpoint: Output<String>? = null

    /**
     * @param value The password of the administrator user account of the catalog database.
     */
    @JvmName("kbjqnfwvtngvyuto")
    public suspend fun catalogAdminPassword(`value`: Output<SecureStringArgs>) {
        this.catalogAdminPassword = value
    }

    /**
     * @param value The administrator user name of catalog database.
     */
    @JvmName("lhxljesmnlqiislj")
    public suspend fun catalogAdminUserName(`value`: Output<String>) {
        this.catalogAdminUserName = value
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("cwuggmwtrpvkfxad")
    public suspend
    fun catalogPricingTier(`value`: Output<Either<String, IntegrationRuntimeSsisCatalogPricingTier>>) {
        this.catalogPricingTier = value
    }

    /**
     * @param value The catalog database server URL.
     */
    @JvmName("fnxedwkrjbfjeiat")
    public suspend fun catalogServerEndpoint(`value`: Output<String>) {
        this.catalogServerEndpoint = value
    }

    /**
     * @param value The password of the administrator user account of the catalog database.
     */
    @JvmName("mlgdxwycwrqyijaa")
    public suspend fun catalogAdminPassword(`value`: SecureStringArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogAdminPassword = mapped
    }

    /**
     * @param argument The password of the administrator user account of the catalog database.
     */
    @JvmName("clrfkgbmycjocyvp")
    public suspend fun catalogAdminPassword(argument: suspend SecureStringArgsBuilder.() -> Unit) {
        val toBeMapped = SecureStringArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.catalogAdminPassword = mapped
    }

    /**
     * @param value The administrator user name of catalog database.
     */
    @JvmName("irayhkmbnrftxvqe")
    public suspend fun catalogAdminUserName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogAdminUserName = mapped
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("cxrwfnlyowxawbdw")
    public suspend
    fun catalogPricingTier(`value`: Either<String, IntegrationRuntimeSsisCatalogPricingTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogPricingTier = mapped
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("qdligwccqoxrhsvp")
    public fun catalogPricingTier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationRuntimeSsisCatalogPricingTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.catalogPricingTier = mapped
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("kwbshqjlilltpmix")
    public fun catalogPricingTier(`value`: IntegrationRuntimeSsisCatalogPricingTier) {
        val toBeMapped = Either.ofRight<String, IntegrationRuntimeSsisCatalogPricingTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.catalogPricingTier = mapped
    }

    /**
     * @param value The catalog database server URL.
     */
    @JvmName("orbuvfnqxkxfolkm")
    public suspend fun catalogServerEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogServerEndpoint = mapped
    }

    internal fun build(): IntegrationRuntimeSsisCatalogInfoArgs =
        IntegrationRuntimeSsisCatalogInfoArgs(
            catalogAdminPassword = catalogAdminPassword,
            catalogAdminUserName = catalogAdminUserName,
            catalogPricingTier = catalogPricingTier,
            catalogServerEndpoint = catalogServerEndpoint,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/IntegrationRuntimeSsisCatalogInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs.builder
import com.pulumi.azurenative.synapse.kotlin.enums.IntegrationRuntimeSsisCatalogPricingTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Catalog information for managed dedicated integration runtime.
 * @property catalogAdminPassword The password of the administrator user account of the catalog database.
 * @property catalogAdminUserName The administrator user name of catalog database.
 * @property catalogPricingTier The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
 * @property catalogServerEndpoint The catalog database server URL.
 */
public data class IntegrationRuntimeSsisCatalogInfoArgs(
    public val catalogAdminPassword: Output<SecureStringArgs>? = null,
    public val catalogAdminUserName: Output<String>? = null,
    public val catalogPricingTier: Output<Either<String, IntegrationRuntimeSsisCatalogPricingTier>>? =
        null,
    public val catalogServerEndpoint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs =
        com.pulumi.azurenative.synapse.inputs.IntegrationRuntimeSsisCatalogInfoArgs.builder()
            .catalogAdminPassword(
                catalogAdminPassword?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .catalogAdminUserName(catalogAdminUserName?.applyValue({ args0 -> args0 }))
            .catalogPricingTier(
                catalogPricingTier?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .catalogServerEndpoint(catalogServerEndpoint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IntegrationRuntimeSsisCatalogInfoArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeSsisCatalogInfoArgsBuilder internal constructor() {
    private var catalogAdminPassword: Output<SecureStringArgs>? = null

    private var catalogAdminUserName: Output<String>? = null

    private var catalogPricingTier: Output<Either<String, IntegrationRuntimeSsisCatalogPricingTier>>? =
        null

    private var catalogServerEndpoint: Output<String>? = null

    /**
     * @param value The password of the administrator user account of the catalog database.
     */
    @JvmName("owjsijijanwqjdjx")
    public suspend fun catalogAdminPassword(`value`: Output<SecureStringArgs>) {
        this.catalogAdminPassword = value
    }

    /**
     * @param value The administrator user name of catalog database.
     */
    @JvmName("yktgbtfmiuwluesu")
    public suspend fun catalogAdminUserName(`value`: Output<String>) {
        this.catalogAdminUserName = value
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("lxfetbnsfpailtal")
    public suspend
    fun catalogPricingTier(`value`: Output<Either<String, IntegrationRuntimeSsisCatalogPricingTier>>) {
        this.catalogPricingTier = value
    }

    /**
     * @param value The catalog database server URL.
     */
    @JvmName("hgskomxsfhdbeebi")
    public suspend fun catalogServerEndpoint(`value`: Output<String>) {
        this.catalogServerEndpoint = value
    }

    /**
     * @param value The password of the administrator user account of the catalog database.
     */
    @JvmName("axbwwqplqqrfyaia")
    public suspend fun catalogAdminPassword(`value`: SecureStringArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogAdminPassword = mapped
    }

    /**
     * @param argument The password of the administrator user account of the catalog database.
     */
    @JvmName("ydcourrfjvwgksaa")
    public suspend fun catalogAdminPassword(argument: suspend SecureStringArgsBuilder.() -> Unit) {
        val toBeMapped = SecureStringArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.catalogAdminPassword = mapped
    }

    /**
     * @param value The administrator user name of catalog database.
     */
    @JvmName("eoyevwkuqrhotbtc")
    public suspend fun catalogAdminUserName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogAdminUserName = mapped
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("rhplbcpiimiquthd")
    public suspend
    fun catalogPricingTier(`value`: Either<String, IntegrationRuntimeSsisCatalogPricingTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogPricingTier = mapped
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("hthymrraratqdrbp")
    public fun catalogPricingTier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationRuntimeSsisCatalogPricingTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.catalogPricingTier = mapped
    }

    /**
     * @param value The pricing tier for the catalog database. The valid values could be found in https://azure.microsoft.com/en-us/pricing/details/sql-database/
     */
    @JvmName("ojghfcpqrdoonxre")
    public fun catalogPricingTier(`value`: IntegrationRuntimeSsisCatalogPricingTier) {
        val toBeMapped = Either.ofRight<String, IntegrationRuntimeSsisCatalogPricingTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.catalogPricingTier = mapped
    }

    /**
     * @param value The catalog database server URL.
     */
    @JvmName("enfuqhjffbtvbdaf")
    public suspend fun catalogServerEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogServerEndpoint = mapped
    }

    internal fun build(): IntegrationRuntimeSsisCatalogInfoArgs =
        IntegrationRuntimeSsisCatalogInfoArgs(
            catalogAdminPassword = catalogAdminPassword,
            catalogAdminUserName = catalogAdminUserName,
            catalogPricingTier = catalogPricingTier,
            catalogServerEndpoint = catalogServerEndpoint,
        )
}
